@@ -16,13 +16,6 @@
 
 package org.jbpm.workbench.wi.backend.server.dd;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.when;
-
 import org.guvnor.common.services.project.builder.model.BuildResults;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jbpm.designer.notification.DesignerWorkitemInstalledEvent;
@@ -32,8 +25,8 @@ import org.jbpm.workbench.wi.dd.model.ItemObjectModel;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.services.shared.project.KieProject;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.services.shared.project.KieModule;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.Mock;
 import org.mockito.Mockito;
 import org.mockito.runners.MockitoJUnitRunner;
@@ -42,6 +35,19 @@ import org.uberfire.io.IOService;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.ResourceAddedEvent;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyObject;
+import static org.mockito.Matchers.anyString;
+import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
+
 @RunWith(MockitoJUnitRunner.class)
 public class DDConfigUpdaterTest {
 
@@ -51,7 +57,7 @@ public class DDConfigUpdaterTest {
     private IOService ioService;
 
     @Mock
-    private KieProjectService projectService;
+    private KieModuleService moduleService;
 
     @Mock
     private DDEditorServiceImpl ddEditorService;
@@ -67,19 +73,19 @@ public class DDConfigUpdaterTest {
         model = new DeploymentDescriptorModel();
         model.setOverview(new Overview());
         ddConfigUpdater = new DDConfigUpdater(ddEditorService,
-                                              projectService,
+                                              moduleService,
                                               ioService,
                                               configUpdaterHelper);
 
         Path rootPath = Mockito.mock(Path.class);
-        when(rootPath.toURI()).thenReturn("default://project");
-        KieProject project = Mockito.mock(KieProject.class);
-        when(project.getRootPath()).thenReturn(rootPath);
+        when(rootPath.toURI()).thenReturn("default://");
+        KieModule module = Mockito.mock(KieModule.class);
+        when(module.getRootPath()).thenReturn(rootPath);
 
         when(ioService.exists(any(org.uberfire.java.nio.file.Path.class))).thenReturn(true);
         when(configUpdaterHelper.isPersistenceFile(any(Path.class))).thenReturn(true);
-        when(configUpdaterHelper.buildJPAMarshallingStrategyValue(any(KieProject.class))).thenReturn(JPA_MARSHALLING_STRATEGY);
-        when(projectService.resolveProject(any(Path.class))).thenReturn(project);
+        when(configUpdaterHelper.buildJPAMarshallingStrategyValue(any(KieModule.class))).thenReturn(JPA_MARSHALLING_STRATEGY);
+        when(moduleService.resolveModule(any(Path.class))).thenReturn(module);
         when(ddEditorService.load(any(Path.class))).thenReturn(model);
     }
 
@@ -307,30 +313,65 @@ public class DDConfigUpdaterTest {
                      ddConfigUpdater.getWorkitemResolver("new com.myhandlers.MyHandler()",
                                                          null));
     }
-    
-    
+
     @Test
-    public void testBPMPostBuildHandler() {
-        
+    public void bpmPostBuildHandler_addsRuntimeStrategyFromDeploymentDescriptor() {
+        final String strategyFromDeploymentDescriptor = "PerProcessInstance";
+
         DeploymentDescriptorModel ddModel = new DeploymentDescriptorModel();
         ddModel.setPersistenceUnitName("test");
-        ddModel.setAuditPersistenceUnitName("test");        
-        ddModel.setRuntimeStrategy("PerProcessInstance");
-        
+        ddModel.setAuditPersistenceUnitName("test");
+        ddModel.setRuntimeStrategy(strategyFromDeploymentDescriptor);
+
         when(ioService.get(any())).thenReturn(null);
         when(ddEditorService.load(any())).thenReturn(ddModel);
-        
+
         BPMPostBuildHandler handler = new BPMPostBuildHandler();
         handler.setDeploymentDescriptorService(ddEditorService);
         handler.setIoService(ioService);
-        
+
         BuildResults results = new BuildResults();
         results.addParameter("RootPath", "default://test-project");
-        
+
         handler.process(results);
-        
+
         String strategy = results.getParameter("RuntimeStrategy");
-        assertEquals("PerProcessInstance", strategy);
-        
+        assertEquals(strategyFromDeploymentDescriptor, strategy);
+    }
+
+    @Test
+    public void bpmPostBuildHandlerDoesNothing_whenDeploymentDescriptorDoesNotExist() {
+        when(ioService.exists(any()))
+                .thenReturn(false);
+
+        BPMPostBuildHandler handler = new BPMPostBuildHandler();
+        handler.setDeploymentDescriptorService(ddEditorService);
+        handler.setIoService(ioService);
+
+        BuildResults results = spy(new BuildResults());
+        results.addParameter("RootPath", "default://test-project");
+        handler.process(results);
+
+        verify(ioService).exists(any());
+        verify(ddEditorService, never())
+                .load(anyObject());
+        verify(results, never())
+                .addParameter(eq("RuntimeStrategy"), anyString());
+    }
+
+    @Test
+    public void bpmPostBuildHandlerDoesNothing_whenBuildResultHasNoBuildPath() {
+        BPMPostBuildHandler handler = new BPMPostBuildHandler();
+        handler.setDeploymentDescriptorService(ddEditorService);
+        handler.setIoService(ioService);
+
+        // resultToProcess doesn't have "RootPath" parameter specified
+        BuildResults resultToProcess = spy(new BuildResults());
+        handler.process(resultToProcess);
+
+        verify(ddEditorService, never())
+                .load(anyObject());
+        verify(resultToProcess, never())
+                .addParameter(eq("RuntimeStrategy"), anyString());
     }
 }
\ No newline at end of file
