@@ -33,8 +33,6 @@ public interface Constants extends Messages {
 
     String No_Process_Definitions_Found();
 
-    String Reload_Repository();
-
     String Name();
 
     String Version();
@@ -45,10 +43,6 @@ public interface Constants extends Messages {
 
     String Start();
 
-    String End();
-
-    String Status();
-
     String Signal();
 
     String Abort();
@@ -79,8 +73,6 @@ public interface Constants extends Messages {
 
     String Initiator();
 
-    String Process_Instances_Refreshed();
-
     String No_Process_Instances_Found();
 
     String Aborting_Process_Instance_Not_Allowed(Object id);
@@ -95,13 +87,7 @@ public interface Constants extends Messages {
 
     String Bulk_Signal();
 
-    String Related_To_Me();
-
-    String Showing();
-
-    String Filter();
-
-    String Process_Instances();
+    String ProcessInstanceBreadcrumb(Long processInstanceId);
 
     String History();
 
@@ -115,8 +101,6 @@ public interface Constants extends Messages {
 
     String No_Variables_Available();
 
-    String Refresh();
-
     String View_Process_Instances();
 
     String New_Process_Instance();
@@ -139,32 +123,20 @@ public interface Constants extends Messages {
 
     String Process_Variables();
 
-    String Process_Definition_Details();
-
-    String Process_Definition_Details_Refreshed();
-
     String Previous_Value();
 
     String No_History_For_This_Variable();
 
-    String Process_Definitions();
+    String ProcessDefinitionBreadcrumb(String title);
 
     String Process_Instance_Details();
 
-    String Process_Instance_ID();
-
-    String Process_Definition_Package();
-
     String Process_Definition_Version();
 
     String Process_Instance_State();
 
     String Current_Activities();
 
-    String Process_Instance_Log();
-
-    String Process_Instances_Details_Refreshed();
-
     String Clear();
 
     String Save();
@@ -173,40 +145,20 @@ public interface Constants extends Messages {
 
     String Variable_Value();
 
-    String Variables_History();
-
-    String Signalling_Process_Instance();
-
     String Signal_Data();
 
     String Signal_Name();
 
-    String Process_Diagram();
-
-    String Please_Wait();
-
-    String Processes_Refreshed_From_The_Repo();
+    String Diagram();
 
     String Bulk_Actions();
 
-    String Process_Variable_History();
-
-    String Process_Definitions_Refreshed();
-
     String Options();
 
     String Definition_Details();
 
-    String New_Instance();
-
     String Bulk_Abort();
 
-    String Process_Model();
-
-    String Views();
-
-    String Process_Variables_Refreshed();
-
     String Services();
 
     String Id();
@@ -215,15 +167,11 @@ public interface Constants extends Messages {
 
     String Logs();
 
-    String Get_Instance_Data();
-
     String No_Documents_Available();
 
     String Documents();
 
-    String download();
-
-    String Last_Modified();
+    String Download();
 
     String Size();
 
@@ -235,12 +183,8 @@ public interface Constants extends Messages {
 
     String Asc_Log_Order();
 
-    String Process_Instance_Name();
-
     String Process_Instance_Description();
 
-    String Select();
-
     String Active_Tasks();
 
     String Owner();
@@ -253,28 +197,14 @@ public interface Constants extends Messages {
 
     String Ok();
 
-    String FilterManagement();
-
-    String Close();
-
     String Correlation_Key();
 
     String Last_Modification_Date();
 
     String Last_Modification_Date_Placeholder();
 
-    String Process_DeploymentId();
-
-    String Basic();
-
-    String Advanced();
-
-    String Form();
-
     String Parent_Process_Instance();
 
-    String ParentProcessInstanceId();
-
     String No_Parent_Process_Instance();
 
     String New_Process_InstanceList();
@@ -287,18 +217,8 @@ public interface Constants extends Messages {
 
     String UnexpectedError(String message);
 
-    String ErrorRetrievingProcessDefinitions(String message);
-
     String ErrorRetrievingProcessVariables(String message);
 
-    String Outcome();
-
-    String Duration();
-
-    String Identity();
-
-    String ExternalId();
-
     String NoSubprocessesRequiredByThisProcess();
 
     String NoProcessVariablesDefinedForThisProcess();
@@ -313,12 +233,8 @@ public interface Constants extends Messages {
 
     String AccessDocument();
 
-    String ProcessInstanceNeedsToBeActiveInOrderToBeAborted();
-
     String SelectServerTemplate();
 
-    String ErrorCountNumberView(@PluralCount int errCount);
-
     String FilterByProcessInstanceId();
 
     String FilterByInitiator();
@@ -327,9 +243,9 @@ public interface Constants extends Messages {
 
     String FilterByDescription();
 
-    String HasAtLeastOneError();
+    String WithErrors();
 
-    String HasNoErrors();
+    String WithoutErrors();
 
     String ViewJobs();
 
@@ -338,4 +254,34 @@ public interface Constants extends Messages {
     String ViewErrors();
 
     String ResourceCouldNotBeLoaded(String resource);
+
+    String Task();
+
+    String Process();
+
+    String Human();
+
+    String System();
+
+    String WasStarted();
+
+    String WasCompleted();
+
+    String Process_SLA_Compliance();
+    
+    String SlaNA();
+    
+    String SlaPending();
+    
+    String SlaMet();
+    
+    String SlaAborted();
+    
+    String SlaViolated();
+    
+    String SlaCompliance();
+    
+    String SlaDueDate();
+
+    String Process_Diagram_Not_Found();
 }
