@@ -15,15 +15,18 @@
  */
 package org.jbpm.workbench.pr.client.editors.instance.list;
 
-import java.util.*;
-import java.util.function.Consumer;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Date;
+import java.util.List;
+import java.util.Random;
+import java.util.Set;
 import java.util.function.Predicate;
 
 import com.google.common.collect.Lists;
 import com.google.gwt.dev.util.collect.HashSet;
 import com.google.gwt.view.client.Range;
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.apache.commons.lang3.RandomStringUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.dashbuilder.common.client.error.ClientRuntimeError;
 import org.dashbuilder.dataset.DataSet;
@@ -34,10 +37,16 @@ import org.dashbuilder.dataset.filter.ColumnFilter;
 import org.dashbuilder.dataset.filter.DataSetFilter;
 import org.dashbuilder.dataset.sort.SortOrder;
 import org.jboss.errai.security.shared.api.identity.User;
-import org.jbpm.workbench.common.client.events.SearchEvent;
+import org.jbpm.workbench.common.client.PerspectiveIds;
+import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
+import org.jbpm.workbench.common.client.filters.basic.BasicFilterAddEvent;
+import org.jbpm.workbench.common.client.filters.basic.BasicFilterRemoveEvent;
 import org.jbpm.workbench.common.client.list.ExtendedPagedTable;
+import org.jbpm.workbench.common.client.list.ListTable;
+import org.jbpm.workbench.common.client.menu.ServerTemplateSelectorMenuBuilder;
 import org.jbpm.workbench.df.client.filter.FilterSettings;
 import org.jbpm.workbench.df.client.filter.FilterSettingsJSONMarshaller;
+import org.jbpm.workbench.df.client.filter.FilterSettingsManager;
 import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
 import org.jbpm.workbench.pr.client.editors.instance.signal.ProcessInstanceSignalPresenter;
 import org.jbpm.workbench.pr.client.resources.i18n.Constants;
@@ -53,8 +62,13 @@ import org.mockito.Mock;
 import org.mockito.Spy;
 import org.mockito.invocation.InvocationOnMock;
 import org.mockito.stubbing.Answer;
+import org.uberfire.client.mvp.PerspectiveActivity;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.mocks.CallerMock;
+import org.uberfire.mvp.Command;
+import org.uberfire.mvp.Commands;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.security.ResourceRef;
 import org.uberfire.security.authz.AuthorizationManager;
@@ -65,7 +79,6 @@ import static org.dashbuilder.dataset.filter.FilterFactory.equalsTo;
 import static org.dashbuilder.dataset.filter.FilterFactory.likeTo;
 import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_DEFINITION_ID;
 import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_INSTANCE_ID;
-import static org.jbpm.workbench.common.client.list.AbstractMultiGridView.TAB_SEARCH;
 import static org.jbpm.workbench.pr.model.ProcessInstanceDataSetConstants.*;
 import static org.junit.Assert.*;
 import static org.kie.workbench.common.workbench.client.PerspectiveIds.*;
@@ -74,6 +87,10 @@ import static org.mockito.Mockito.*;
 @RunWith(GwtMockitoTestRunner.class)
 public class ProcessInstanceListPresenterTest {
 
+    private static final String PERSPECTIVE_ID = PerspectiveIds.PROCESS_INSTANCES;
+
+    private org.jbpm.workbench.common.client.resources.i18n.Constants commonConstants;
+
     @Mock
     protected PlaceManager placeManager;
 
@@ -98,7 +115,7 @@ public class ProcessInstanceListPresenterTest {
     private DataSetQueryHelper dataSetQueryHelperDomainSpecific;
 
     @Mock
-    private ExtendedPagedTable extendedPagedTable;
+    private ListTable extendedPagedTable;
 
     @Spy
     private FilterSettings filterSettings;
@@ -115,8 +132,23 @@ public class ProcessInstanceListPresenterTest {
     @Mock
     private User identity;
 
+    @Mock
+    ServerTemplateSelectorMenuBuilder serverTemplateSelectorMenuBuilder;
+
+    @Mock
+    UberfireBreadcrumbs breadcrumbs;
+
+    @Mock
+    private PerspectiveManager perspectiveManager;
+
+    @Mock
+    private PerspectiveActivity perspectiveActivity;
+
     private ArrayList<ProcessInstanceSummary> processInstanceSummaries;
 
+    @Mock
+    private FilterSettingsManager filterSettingsManager;
+
     @InjectMocks
     private ProcessInstanceListPresenter presenter;
 
@@ -140,6 +172,8 @@ public class ProcessInstanceListPresenterTest {
                                           "cKey",
                                           Long.valueOf(0),
                                           new Date(),
+                                          0,
+                                          null,
                                           0);
     }
 
@@ -166,13 +200,17 @@ public class ProcessInstanceListPresenterTest {
 
         processInstanceSummaries = createProcessInstanceSummaryList(5);
 
-        when(filterSettings.getDataSetLookup()).thenReturn(dataSetLookup);
+        filterSettings.setKey("key");
+        filterSettings.setDataSetLookup(dataSetLookup);
+
         when(viewMock.getListGrid()).thenReturn(extendedPagedTable);
         when(extendedPagedTable.getPageSize()).thenReturn(10);
         when(filterSettingsJSONMarshaller.fromJsonString(anyString())).thenReturn(filterSettings);
         when(dataSetQueryHelper.getCurrentTableSettings()).thenReturn(filterSettings);
-        when(viewMock.getAdvancedSearchFilterSettings()).thenReturn(filterSettings);
-        when(filterSettings.getKey()).thenReturn("key");
+        when(filterSettingsManager.getVariablesFilterSettings(any())).thenReturn(filterSettings);
+        when(serverTemplateSelectorMenuBuilder.getView()).thenReturn(mock(ServerTemplateSelectorMenuBuilder.ServerTemplateSelectorElementView.class));
+        when(perspectiveManager.getCurrentPerspective()).thenReturn(perspectiveActivity);
+        when(perspectiveActivity.getIdentifier()).thenReturn(PERSPECTIVE_ID);
 
         doAnswer(new Answer() {
 
@@ -193,17 +231,21 @@ public class ProcessInstanceListPresenterTest {
             }
         }).when(dataSetQueryHelperDomainSpecific).lookupDataSet(anyInt(),
                                                                 any(DataSetReadyCallback.class));
+        commonConstants = org.jbpm.workbench.common.client.resources.i18n.Constants.INSTANCE;
 
         presenter.setProcessService(remoteProcessServiceCaller);
     }
 
     @Test
     public void getDataTest() {
-        presenter.setAddingDefaultFilters(false);
         presenter.getData(new Range(0,
                                     5));
 
-        verify(dataSetQueryHelper).setLastSortOrder(SortOrder.ASCENDING);
+        verify(dataSetQueryHelper).lookupDataSet(anyInt(),
+                                                 any(DataSetReadyCallback.class));
+        verify(dataSetQueryHelperDomainSpecific,
+               never()).lookupDataSet(anyInt(),
+                                      any(DataSetReadyCallback.class));
         verify(viewMock,
                times(2)).hideBusyIndicator();
     }
@@ -242,6 +284,7 @@ public class ProcessInstanceListPresenterTest {
         verify(processService).abortProcessInstance(anyString(),
                                                     eq(containerId),
                                                     eq(processInstanceId));
+        verify(viewMock).displayNotification(Constants.INSTANCE.Aborting_Process_Instance(processInstanceId));
     }
 
     @Test
@@ -255,8 +298,8 @@ public class ProcessInstanceListPresenterTest {
         pIds.add(random.nextLong());
         pIds.add(random.nextLong());
 
-        presenter.abortProcessInstance(containers,
-                                       pIds);
+        presenter.abortProcessInstances(containers,
+                                        pIds);
 
         verify(processService).abortProcessInstances(anyString(),
                                                      eq(containers),
@@ -335,31 +378,8 @@ public class ProcessInstanceListPresenterTest {
                                                           null));
     }
 
-    @Test
-    public void testSkipDomainSpecificColumnsForSearchTab() {
-        presenter.setAddingDefaultFilters(false);
-        final DataSetFilter filter = new DataSetFilter();
-        filter.addFilterColumn(equalsTo(COLUMN_PROCESS_ID,
-                                        "testProc"));
-        filterSettings.getDataSetLookup().addOperation(filter);
-        filterSettings.setKey(TAB_SEARCH);
-        when(filterSettings.getKey()).thenReturn(TAB_SEARCH);
-
-        when(dataSet.getRowCount()).thenReturn(1);//1 process instance
-        when(dataSet.getValueAt(0,
-                                COLUMN_PROCESS_INSTANCE_ID)).thenReturn(Long.valueOf(1));
-
-        presenter.getData(new Range(0,
-                                    5));
-
-        verifyZeroInteractions(dataSetQueryHelperDomainSpecific);
-        verify(viewMock,
-               times(2)).hideBusyIndicator();
-    }
-
     @Test
     public void getDomainSpecifDataForProcessInstancesTest() {
-        presenter.setAddingDefaultFilters(false);
         final DataSetFilter filter = new DataSetFilter();
         filter.addFilterColumn(equalsTo(COLUMN_PROCESS_ID,
                                         "testProc"));
@@ -444,85 +464,6 @@ public class ProcessInstanceListPresenterTest {
         return pIList;
     }
 
-    @Test
-    public void testEmptySearchString() {
-        final SearchEvent searchEvent = new SearchEvent("");
-
-        presenter.onSearchEvent(searchEvent);
-
-        verify(viewMock).applyFilterOnPresenter(anyString());
-        assertEquals(searchEvent.getFilter(),
-                     presenter.getTextSearchStr());
-    }
-
-    @Test
-    public void testSearchString() {
-        final SearchEvent searchEvent = new SearchEvent(RandomStringUtils.random(10));
-
-        presenter.onSearchEvent(searchEvent);
-
-        verify(viewMock).applyFilterOnPresenter(anyString());
-        assertEquals(searchEvent.getFilter(),
-                     presenter.getTextSearchStr());
-    }
-
-    @Test
-    public void testSearchFilterEmpty() {
-        final List<ColumnFilter> filters = presenter.getColumnFilters("");
-
-        assertTrue(filters.isEmpty());
-    }
-
-    @Test
-    public void testSearchFilterNull() {
-        final List<ColumnFilter> filters = presenter.getColumnFilters(null);
-
-        assertTrue(filters.isEmpty());
-    }
-
-    @Test
-    public void testSearchFilterEmptyTrim() {
-        final List<ColumnFilter> filters = presenter.getColumnFilters("     ");
-
-        assertTrue(filters.isEmpty());
-    }
-
-    @Test
-    public void testSearchFilterId() {
-        final List<ColumnFilter> filters = presenter.getColumnFilters("1");
-
-        assertEquals(1,
-                     filters.size());
-        assertEquals(COLUMN_PROCESS_INSTANCE_ID,
-                     filters.get(0).getColumnId());
-    }
-
-    @Test
-    public void testSearchFilterIdTrim() {
-        final List<ColumnFilter> filters = presenter.getColumnFilters(" 1 ");
-
-        assertEquals(1,
-                     filters.size());
-        assertEquals(COLUMN_PROCESS_INSTANCE_ID,
-                     filters.get(0).getColumnId());
-    }
-
-    @Test
-    public void testSearchFilterString() {
-        final List<ColumnFilter> filters = presenter.getColumnFilters("processName");
-
-        assertEquals(4,
-                     filters.size());
-        assertEquals(COLUMN_PROCESS_ID,
-                     filters.get(0).getColumnId());
-        assertEquals(COLUMN_PROCESS_NAME,
-                     filters.get(1).getColumnId());
-        assertEquals(COLUMN_PROCESS_INSTANCE_DESCRIPTION,
-                     filters.get(2).getColumnId());
-        assertEquals(COLUMN_IDENTITY,
-                     filters.get(3).getColumnId());
-    }
-
     @Test
     public void testDataSetQueryHelperColumnMapping() {
         final Long TEST_PROC_INST_ID = Long.valueOf(55);
@@ -606,10 +547,17 @@ public class ProcessInstanceListPresenterTest {
     public void testDefaultActiveSearchFilters() {
         presenter.setupDefaultActiveSearchFilters();
 
-        verify(viewMock).addActiveFilter(eq(Constants.INSTANCE.State()),
-                                         eq(Constants.INSTANCE.Active()),
-                                         eq(String.valueOf(ProcessInstance.STATE_ACTIVE)),
-                                         any(Consumer.class));
+        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
+        verify(viewMock).addActiveFilter(captor.capture());
+
+        assertEquals(1,
+                     captor.getAllValues().size());
+        assertEquals(Constants.INSTANCE.State(),
+                     captor.getValue().getKey());
+        assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active(),
+                     captor.getValue().getLabelValue());
+        assertEquals(String.valueOf(ProcessInstance.STATE_ACTIVE),
+                     (captor.getValue().getValue()));
     }
 
     @Test
@@ -621,10 +569,17 @@ public class ProcessInstanceListPresenterTest {
 
         presenter.setupActiveSearchFilters();
 
-        verify(viewMock).addActiveFilter(eq(Constants.INSTANCE.State()),
-                                         eq(Constants.INSTANCE.Active()),
-                                         eq(String.valueOf(ProcessInstance.STATE_ACTIVE)),
-                                         any(Consumer.class));
+        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
+        verify(viewMock).addActiveFilter(captor.capture());
+
+        assertEquals(1,
+                     captor.getAllValues().size());
+        assertEquals(Constants.INSTANCE.State(),
+                     captor.getValue().getKey());
+        assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active(),
+                     captor.getValue().getLabelValue());
+        assertEquals(String.valueOf(ProcessInstance.STATE_ACTIVE),
+                     (captor.getValue().getValue()));
     }
 
     @Test
@@ -637,10 +592,17 @@ public class ProcessInstanceListPresenterTest {
 
         presenter.setupActiveSearchFilters();
 
-        verify(viewMock).addActiveFilter(eq(Constants.INSTANCE.Process_Definition_Id()),
-                                         eq(processDefinitionId),
-                                         eq(processDefinitionId),
-                                         any(Consumer.class));
+        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
+        verify(viewMock).addActiveFilter(captor.capture());
+
+        assertEquals(1,
+                     captor.getAllValues().size());
+        assertEquals(Constants.INSTANCE.Process_Definition_Id(),
+                     captor.getValue().getKey());
+        assertEquals(Constants.INSTANCE.Process_Definition_Id() + ": " + processDefinitionId,
+                     captor.getValue().getLabelValue());
+        assertEquals(processDefinitionId,
+                     (captor.getValue().getValue()));
     }
 
     @Test
@@ -655,10 +617,17 @@ public class ProcessInstanceListPresenterTest {
 
         presenter.setupActiveSearchFilters();
 
-        verify(viewMock).addActiveFilter(eq(Constants.INSTANCE.Id()),
-                                         eq(processInstanceId),
-                                         eq(processInstanceId),
-                                         any(Consumer.class));
+        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
+        verify(viewMock).addActiveFilter(captor.capture());
+
+        assertEquals(1,
+                     captor.getAllValues().size());
+        assertEquals(Constants.INSTANCE.Id(),
+                     captor.getValue().getKey());
+        assertEquals(Constants.INSTANCE.Id() + ": " + processInstanceId,
+                     captor.getValue().getLabelValue());
+        assertEquals(processInstanceId,
+                     (captor.getValue().getValue()));
     }
 
     @Test
@@ -777,12 +746,64 @@ public class ProcessInstanceListPresenterTest {
         final ProcessInstanceListPresenter spy = spy(presenter);
         final ClientRuntimeError error = new ClientRuntimeError("");
         final FilterSettings filterSettings = mock(FilterSettings.class);
-        final DataSetReadyCallback callback = spy.createDataSetProcessInstanceCallback(0,
-                                                                                       filterSettings);
+        final DataSetReadyCallback callback = spy.getDataSetReadyCallback(0,
+                                                                          filterSettings);
         doNothing().when(spy).showErrorPopup(any());
         assertFalse(callback.onError(error));
         verify(viewMock).hideBusyIndicator();
-        verify(spy).showErrorPopup(Constants.INSTANCE.ResourceCouldNotBeLoaded(Constants.INSTANCE.Process_Instances()));
+        verify(spy).showErrorPopup(Constants.INSTANCE.ResourceCouldNotBeLoaded(commonConstants.Process_Instances()));
+    }
+
+    @Test
+    public void testListBreadcrumbCreation() {
+        presenter.createListBreadcrumb();
+        ArgumentCaptor<Command> captureCommand = ArgumentCaptor.forClass(Command.class);
+        verify(breadcrumbs).clearBreadcrumbs(PERSPECTIVE_ID);
+        verify(breadcrumbs).addBreadCrumb(eq(PERSPECTIVE_ID),
+                                          eq(commonConstants.Home()),
+                                          captureCommand.capture());
+
+        captureCommand.getValue().execute();
+        verify(placeManager).goTo(PerspectiveIds.HOME);
+
+        verify(breadcrumbs).addBreadCrumb(eq(PERSPECTIVE_ID),
+                                          eq(commonConstants.Manage_Process_Instances()),
+                                          eq(Commands.DO_NOTHING));
+
+        verifyNoMoreInteractions(breadcrumbs);
+    }
+
+    @Test
+    public void testSetupDetailBreadcrumb() {
+        String detailLabel = "detailLabel";
+        String detailScreenId = "screenId";
+
+        PlaceManager placeManagerMock = mock(PlaceManager.class);
+        presenter.setPlaceManager(placeManagerMock);
+        presenter.setupDetailBreadcrumb(placeManagerMock,
+                                        commonConstants.Manage_Process_Instances(),
+                                        detailLabel,
+                                        detailScreenId);
+
+        ArgumentCaptor<Command> captureCommand = ArgumentCaptor.forClass(Command.class);
+
+        verify(breadcrumbs).clearBreadcrumbs(PERSPECTIVE_ID);
+        verify(breadcrumbs).addBreadCrumb(eq(PERSPECTIVE_ID),
+                                          eq(commonConstants.Home()),
+                                          captureCommand.capture());
+        captureCommand.getValue().execute();
+        verify(placeManagerMock).goTo(PerspectiveIds.HOME);
+
+        verify(breadcrumbs).addBreadCrumb(eq(PERSPECTIVE_ID),
+                                          eq(commonConstants.Manage_Process_Instances()),
+                                          captureCommand.capture());
+
+        captureCommand.getValue().execute();
+        verify(placeManagerMock).closePlace(detailScreenId);
+
+        verify(breadcrumbs).addBreadCrumb(eq(PERSPECTIVE_ID),
+                                          eq(detailLabel),
+                                          eq(Commands.DO_NOTHING));
     }
 
     protected class PerspectiveAnswer implements Answer<Boolean> {
@@ -798,4 +819,35 @@ public class ProcessInstanceListPresenterTest {
             return perspectiveId.equals(((ResourceRef) invocation.getArguments()[0]).getIdentifier());
         }
     }
+
+    @Test
+    public void testOnBasicFilterAddEvent() {
+        final ActiveFilterItem<Object> filter = new ActiveFilterItem<>("key1",
+                                                                       null,
+                                                                       null,
+                                                                       null,
+                                                                       null);
+        final ColumnFilter columnFilter = mock(ColumnFilter.class);
+        presenter.onBasicFilterAddEvent(new BasicFilterAddEvent(filter,
+                                                                columnFilter));
+
+        verify(viewMock).addActiveFilter(filter);
+        verify(filterSettings).addColumnFilter(columnFilter);
+    }
+
+    @Test
+    public void testOnBasicFilterRemoveEvent() {
+        final ActiveFilterItem<Object> filter = new ActiveFilterItem<>("key1",
+                                                                       null,
+                                                                       null,
+                                                                       null,
+                                                                       null);
+        final ColumnFilter columnFilter = mock(ColumnFilter.class);
+        presenter.onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(filter,
+                                                                      columnFilter));
+
+        verify(viewMock).removeActiveFilter(filter);
+        verify(filterSettings).removeColumnFilter(columnFilter);
+    }
+
 }
